@@ -12,6 +12,7 @@
 #include "scpinstaller.h"
 #endif
 
+#include <QCommandLineParser>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusMetaType>
@@ -23,7 +24,6 @@
 #include <KOSRelease>
 
 #include <KCupsRequest.h>
-#include <PPDModel.h>
 #include <cups/adminutil.h>
 #include <cups/ppd.h>
 
@@ -47,7 +47,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, DriverMatch &driv
     return argument;
 }
 
-PrinterManager::PrinterManager(QObject *parent, const KPluginMetaData &metaData)
+PrinterManager::PrinterManager(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : KQuickConfigModule(parent, metaData)
     , m_serverSettings({{QLatin1String(CUPS_SERVER_USER_CANCEL_ANY), false},
                         {QLatin1String(CUPS_SERVER_SHARE_PRINTERS), false},
@@ -89,6 +89,49 @@ PrinterManager::PrinterManager(QObject *parent, const KPluginMetaData &metaData)
 #ifdef SCP_INSTALL
     qmlRegisterType<SCPInstaller>("org.kde.plasma.printmanager", 1, 0, "SCPInstaller");
 #endif
+
+    // If activation requested, set command line args and notify
+    connect(this, &PrinterManager::activationRequested, this, &PrinterManager::processCmdLine);
+    // Handle command line args
+    if (!args.isEmpty()) {
+        connect(this, &PrinterManager::mainUiReady, this, [this,args] {
+            processCmdLine(args);
+        }, Qt::SingleShotConnection);
+    }
+}
+
+void PrinterManager::processCmdLine(const QVariantList &args) {
+    qCDebug(PMKCM) << Q_FUNC_INFO << args;
+    QCommandLineParser parser;
+    QCommandLineOption addPrinter(u"add-printer"_s, i18n("Add a new printer"));
+    parser.addOption(addPrinter);
+    QCommandLineOption addGroup(u"add-group"_s, i18n("Add a new printer group"));
+    parser.addOption(addGroup);
+    QCommandLineOption confPrinter(u"configure-printer"_s, i18n("Configure a printer"), u"printerName"_s);
+    parser.addOption(confPrinter);
+    QCommandLineOption chgPrinter(u"change-printer-ppd"_s, i18n("Configure a printer"), u"printerName"_s);
+    parser.addOption(chgPrinter);
+
+    // Convert Variants to Strings; parse() needs the binary as the first arg
+    QStringList list(u"systemsettings"_s);
+    for(auto &v: args) {
+        list << v.toString();
+    }
+    parser.parse(list);
+
+    if (parser.isSet(addPrinter)) {
+        Q_EMIT cmdAddPrinter();
+        return;
+    }
+
+    if (parser.isSet(addGroup)) {
+        Q_EMIT cmdAddGroup();
+        return;
+    }
+
+    if (parser.isSet(confPrinter) || parser.isSet(chgPrinter)) {
+        Q_EMIT cmdConfigurePrinter(parser.value(confPrinter));
+    }
 }
 
 void PrinterManager::initOSRelease()
@@ -208,8 +251,16 @@ void PrinterManager::savePrinter(const QString &name, const QVariantMap &saveArg
         args[KCUPS_PRINTER_STATE] = IPP_PRINTER_IDLE;
     }
 
+    // WORKAROUND: Remove after CUPS 2.4.13 release
+    // CUPS Issue #1235 (https://github.com/OpenPrinting/cups/issues/1235)
+    // Fixed in 2.4.13+/2.5 (N/A in CUPS 3.x)
+    const bool forceRefresh = !addMode
+            && (args.value(u"ppd-name"_s) == u"everywhere"_s)
+            && (QVersionNumber(CUPS_VERSION_MAJOR, CUPS_VERSION_MINOR, CUPS_VERSION_PATCH) < QVersionNumber(2,4,13));
+
     qCDebug(PMKCM) << (addMode ? "New Printer:" : "Change Printer:") << name << "isClass?" << isClass << "Changing Default?" << isDefault << "filename"
                    << fileName << Qt::endl
+                   << "forceRefresh" << forceRefresh << Qt::endl
                    << "args" << args;
 
     auto request = new KCupsRequest;
@@ -241,19 +292,19 @@ void PrinterManager::savePrinter(const QString &name, const QVariantMap &saveArg
             request->setDefaultPrinter(name);
         }
         request->deleteLater();
-        Q_EMIT saveDone();
+        Q_EMIT saveDone(forceRefresh);
     } else {
-        connect(request, &KCupsRequest::finished, this, [this, isClass, name, isDefault](KCupsRequest *req) {
+        connect(request, &KCupsRequest::finished, this, [this, isClass, name, isDefault, forceRefresh](KCupsRequest *req) {
             if (!req->hasError()) {
                 // Also check default printer flag
                 if (isDefault) {
                     qCDebug(PMKCM) << "Saving printer DEFAULT:" << name;
-                    auto r = setupRequest([this]() {
-                        Q_EMIT saveDone();
+                    auto r = setupRequest([this, forceRefresh]() {
+                        Q_EMIT saveDone(forceRefresh);
                     });
                     r->setDefaultPrinter(name);
                 } else {
-                    Q_EMIT saveDone();
+                    Q_EMIT saveDone(forceRefresh);
                 }
             } else {
                 Q_EMIT requestError((isClass ? i18nc("@info", "Failed to configure class: ") : i18nc("@info", "Failed to configure printer: "))
@@ -354,18 +405,6 @@ void PrinterManager::loadPrinterPPD(const QString &name)
     });
 }
 
-void PrinterManager::pausePrinter(const QString &name)
-{
-    const auto request = setupRequest();
-    request->pausePrinter(name);
-}
-
-void PrinterManager::resumePrinter(const QString &name)
-{
-    const auto request = setupRequest();
-    request->resumePrinter(name);
-}
-
 bool PrinterManager::isIPPCapable(const QString &uri)
 {
     /**
@@ -390,6 +429,14 @@ void PrinterManager::getRecommendedDrivers(const QString &deviceId, const QStrin
     qCDebug(PMKCM) << "getRecommendedDrivers for:" << makeAndModel << deviceUri << deviceId;
 
     m_recommendedDrivers.clear();
+    // Add entry for the ipp everywhere driver
+    if (isIPPCapable(deviceUri)) {
+        m_recommendedDrivers.append(QVariantMap({{u"favorite"_s, true},
+                                                 {u"title"_s, i18nc("@list:item", "IPP Everywhere™")},
+                                                 {u"match"_s, u"exact-cmd"_s},
+                                                 {u"ppd-name"_s, u"everywhere"_s},
+                                                 {u"ppd-type"_s, PMTypes::Auto}}));
+    }
 
     auto call = QDBusMessage::createMethodCall(u"org.fedoraproject.Config.Printing"_s,
                                                u"/org/fedoraproject/Config/Printing"_s,
@@ -409,7 +456,19 @@ void PrinterManager::getRecommendedDrivers(const QString &deviceId, const QStrin
                 if (driverMatch.match == u"none"_s) {
                     continue;
                 }
-                m_recommendedDrivers.append(QVariantMap({{u"match"_s, driverMatch.match}, {u"ppd-name"_s, driverMatch.ppd}, {u"ppd-type"_s, PMTypes::Auto}}));
+                QString title(driverMatch.ppd);
+                bool favorite = false;
+                if (title.contains(u"driverless"_s)) {
+                    title = i18nc("@list:item", "Driverless");
+                    favorite = true;
+                } else if (title.contains(u"ppd"_s)) {
+                    title = i18nc("@list:item", "PPD File");
+                }
+                m_recommendedDrivers.append(QVariantMap({{u"favorite"_s, favorite},
+                                                         {u"title"_s, title},
+                                                         {u"match"_s, driverMatch.match},
+                                                         {u"ppd-name"_s, driverMatch.ppd},
+                                                         {u"ppd-type"_s, PMTypes::Auto}}));
             }
         }
         Q_EMIT recommendedDriversLoaded();
